Command line interface.
Structs
- Command line interface for running a
Rulesetagainst a CSV file. Cliconfiguration options specific to how to parse the CSV file.- Configuration options for the
Cli.
Command line interface.
Ruleset against a CSV file.Cli configuration options specific to how to parse the CSV file.Cli.