pub struct CsvOptions {
pub delimiter: u8,
pub record_terminator: RecordTerminator,
pub quote: u8,
pub escape: Option<u8>,
pub double_quote: bool,
}Expand description
Cli configuration options specific to how to parse the CSV file.
CsvOptions implements Default with the following defaults:
extern crate csv;
use csv_sanity::cli::CsvOptions;
use csv::RecordTerminator;
let defaults = CsvOptions {
delimiter: b',',
record_terminator: csv::RecordTerminator::CRLF,
quote: b'"',
escape: None,
double_quote: true,
};
assert_eq!(defaults, Default::default());Fields
delimiter: u8Field delimeter to expect in the CSV file.
Corresponds to the csv::Reader.delimiter method.
record_terminator: RecordTerminatorRecord terminator to expect in the CSV file.
Corresponds to the csv::Reader.record_terminator method. See csv::RecordTerminator.
quote: u8Field quotation character to expect in the CSV file.
Corresponds to the csv::Reader.quote method.
escape: Option<u8>Escape character to expect in the CSV file.
Corresponds to the csv::Reader.escape method.
double_quote: boolWhether two adjacent quote characters should be interpreted as an escaped quote character.
Corresponds to the csv::Reader.double_quote method.